MotionWidgetExtensions extension

on

Methods

animateFade({Key? key, double opacity = 1.0, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in an easy implicit animated opacity/fade effect
animateRotation({Key? key, double turns = 0.0, Duration duration = const Duration(milliseconds: 400), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in a rotation effect
animateScale({Key? key, double scale = 1.0, Duration duration = const Duration(milliseconds: 300), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in an easy implicit animated scale effect
animateSlide({Key? key, Offset offset = Offset.zero, Duration duration = const Duration(milliseconds: 350), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in a slide-offset animated wrapper