MotionThemeData class
Constructors
- MotionThemeData({required bool isDark, Color primaryColor = MotionColors.primaryNeon, Color secondaryColor = MotionColors.secondaryNeon, Color backgroundColor = MotionColors.darkBackground, Color surfaceColor = MotionColors.darkSurface, Color cardColor = MotionColors.darkSurfaceCard, bool glowEffect = true, double borderRadius = 16.0, LinearGradient accentGradient = MotionColors.cyberGradient})
- MotionThemeData.dark()
-
factory
- MotionThemeData.light()
-
factory
Properties
- accentGradient → LinearGradient
-
final
- backgroundColor → Color
-
final
- borderRadius → double
-
final
- cardColor → Color
-
final
- glowEffect → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDark → bool
-
final
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor → Color
-
final
- surfaceColor → Color
-
final
- textColor → Color
-
no setter
Methods
-
copyWith(
{bool? isDark, Color? primaryColor, Color? secondaryColor, Color? backgroundColor, Color? surfaceColor, Color? cardColor, bool? glowEffect, double? borderRadius, LinearGradient? accentGradient}) → MotionThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toThemeData(
) → ThemeData
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited