MotionCurves class

Constructors

MotionCurves()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auroraFlow → const Curve
bouncy → const Curve
extremeBouncy → const Curve
fluidIn → const Curve
fluidOut → const Curve
magneticSpring → const Curve
springy → const Curve
swiftOut → const Curve
Custom Cubic Beziers inspired by Apple/Framer Motion