MotionGlassContainer class

Inheritance
Available extensions

Constructors

MotionGlassContainer({Key? key, required Widget child, double blur = 12.0, double opacity = 0.1, double borderRadius = 20.0, BoxBorder? border, Color? color, List<Color>? borderColors, double borderWidth = 1.5, EdgeInsetsGeometry? padding, double? width, double? height})
const

Properties

blur double
final
border BoxBorder?
final
borderColors List<Color>?
final
borderRadius double
final
borderWidth double
final
child Widget
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity double
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

animateFade({Key? key, double opacity = 1.0, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in an easy implicit animated opacity/fade effect
animateRotation({Key? key, double turns = 0.0, Duration duration = const Duration(milliseconds: 400), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in a rotation effect
animateScale({Key? key, double scale = 1.0, Duration duration = const Duration(milliseconds: 300), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in an easy implicit animated scale effect
animateSlide({Key? key, Offset offset = Offset.zero, Duration duration = const Duration(milliseconds: 350), Curve curve = MotionCurves.swiftOut}) Widget

Available on Widget, provided by the MotionWidgetExtensions extension

Wraps a widget in a slide-offset animated wrapper
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited