FloatEffect class

FloatEffect floats the child vertically up and down using a smooth sinusoidal timeline.

Inheritance

Constructors

FloatEffect({double dy = 12.0})
const

Properties

dy double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(BuildContext context, Widget child, double progress) Widget
Wraps the child widget with this specific visual effect.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited