GlitchEffect class

GlitchEffect executes broken RGB digital splits and skews over the child widget.

Inheritance

Constructors

GlitchEffect({double intensity = 5.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
intensity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(BuildContext context, Widget child, double progress) Widget
Wraps the child widget with this specific visual effect.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited