wrap abstract method
Wraps the child widget with this specific visual effect.
Implementation
Widget wrap(BuildContext context, Widget child, double progress);
Wraps the child widget with this specific visual effect.
Widget wrap(BuildContext context, Widget child, double progress);