OrbitEffect class

OrbitEffect rotates the widget child itself or orbits planetary nodes around it.

Inheritance

Constructors

OrbitEffect({double radius = 40.0, double speed = 1.0})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(BuildContext context, Widget child, double progress) Widget
Wraps the child widget with this specific visual effect.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited