RippleEffect class

RippleEffect draws pulsing circular neon waves expanding outwards behind the child.

Inheritance

Constructors

RippleEffect({required Color color, double maxRadius = 60.0})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
maxRadius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(BuildContext context, Widget child, double progress) Widget
Wraps the child widget with this specific visual effect.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited