MotionExperimentalStyle enum

Experimental Theme Category styles & enums.

Inheritance
Available extensions

Values

timeWarp → const MotionExperimentalStyle

Distorted melting clock faces executing temporal blurs and reverse speeds.

portal → const MotionExperimentalStyle

Sci-fi energy vortex portals sucking in floating warp particles.

dimensionalRift → const MotionExperimentalStyle

Cracking spatial rifts leaking neon light beams and glitching.

wormhole → const MotionExperimentalStyle

Zooming 3D tunnel wormholes with glowing cosmic particle stars.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MotionExperimentalStyle>
A constant List of the values in this enum, in order of their declaration.