MotionGamingStyle enum

Gaming Category styles & enums.

Inheritance
Available extensions

Values

xpProgress → const MotionGamingStyle

Circular golden shield progress bar emitting floating level-up energy sparks.

bossFight → const MotionGamingStyle

Dual counter-rotating RPG magic circles emitting radial fire bursts.

pixel → const MotionGamingStyle

Retro arcade style 8-bit glitched grid blocks scaling in sequence.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MotionGamingStyle>
A constant List of the values in this enum, in order of their declaration.