MotionLiquidStyle enum
Liquid Loader styles & enums.
Values
- lavaLamp → const MotionLiquidStyle
-
Gooey lava lamp style liquid blobs morphing and merging together.
- waterDrop → const MotionLiquidStyle
-
Droplets landing on a surface generating fading refraction waves.
- inkSpread → const MotionLiquidStyle
-
Ink diffusing and expanding naturally across a gradient background.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MotionLiquidStyle> - A constant List of the values in this enum, in order of their declaration.