MotionSaasStyle enum

SaaS Category styles & enums.

Inheritance
Available extensions

Values

pulseGrid → const MotionSaasStyle

3x3 Staggered matrix grid cards pulsing opacity like a dashboard placeholder.

analytics → const MotionSaasStyle

Auto-drawing line chart graph showing active analytic metrics data points.

cloudSync → const MotionSaasStyle

Floating sync bubbles entering a bezier cloud while arrows spin.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MotionSaasStyle>
A constant List of the values in this enum, in order of their declaration.