MotionRefreshController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • MotionRefreshController
Implemented types
Mixed-in types
  • GetTickerProviderStateMixin

Constructors

MotionRefreshController({required double triggerDistance, required double settleDistance, required Duration duration, required Duration refreshDuration, required Duration collapseDuration, required Curve collapseCurve, required double animationSpeed, required bool enableHaptics, ScrollController? scrollController})

Properties

activeTween Animatable<double>
getter/setter pair
animationSpeed double
getter/setter pair
collapseCurve Curve
getter/setter pair
collapseDuration Duration
getter/setter pair
duration Duration
getter/setter pair
enableHaptics bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
hasSelectionHapticFired → RxBool
final
hasThresholdBeenReached → RxBool
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isCollapsing → RxBool
final
isRefreshing → RxBool
final
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
pullOffset → RxDouble
final
refreshDuration Duration
getter/setter pair
resetController AnimationController
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
getter/setter pair
settleDistance double
getter/setter pair
tickerController AnimationController
getter/setter pair
triggerDistance double
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
animateToOffset(double target) Future<void>
createTicker(TickerCallback onTick) Ticker
Creates a ticker with the given callback.
inherited
didChangeDependencies(BuildContext context) → void
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onScrollNotification(ScrollNotification notification, Future<void> onRefresh()) → void
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
snapBack(double target) Future<void>
toString() String
A string representation of this object.
inherited
triggerRefresh(Future<void> onRefresh()) Future<void>
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateParameters({required double triggerDistance, required double settleDistance, required Duration duration, required Duration refreshDuration, required Duration collapseDuration, required Curve collapseCurve, required double animationSpeed, required bool enableHaptics, ScrollController? scrollController}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited