collapseCurve property
The curve applied when collapsing the header back to the top. Defaults to Curves.easeInOutCubic for a beautiful, organic easing profile.
Implementation
final Curve collapseCurve;
The curve applied when collapsing the header back to the top. Defaults to Curves.easeInOutCubic for a beautiful, organic easing profile.
final Curve collapseCurve;