showStatusText property
Toggles the rendering of dynamic status helper text (e.g. "Pull to refresh").
Implementation
final bool showStatusText;
Toggles the rendering of dynamic status helper text (e.g. "Pull to refresh").
final bool showStatusText;