loaders/ai/ai_category library
Classes
- MotionAiEyeLoader
- Robotic sci-fi iris eye focusing, dilating, and sweeping scanlines.
- MotionAiThinkingLoader
- Siri / ChatGPT style dynamic breathing wave and rotating gradient ring.
- MotionAiTokenStream
- Simulated LLM Token Streaming character terminal loader.
- MotionNeuralNetworkLoader
- Renders premium AI-themed interactive loaders.
- MotionNeuralPulseLoader
- Neuron branches flashing electric pulses and synapse network signals.
- MotionQuantumLoader
- Quantum teleporting reconnecting particle loader.
- MotionTensorFlowLoader
- 3D-perspective floating data cube matrices translating along streams.
- MotionTokenPredictionLoader
- AI text token generation typing text streams with glowing cursors.
Enums
- MotionAiStyle
- Neural Network Loader styles & enums.