MotionAiStyle enum
Neural Network Loader styles & enums.
Values
- neuralNetwork → const MotionAiStyle
-
Pulsing synaptic nodes connecting dynamically with traveling energy packets.
- thinking → const MotionAiStyle
-
ChatGPT/Gemini style breathing wave and rotating glow rings.
- quantum → const MotionAiStyle
-
Holographic particles quantum teleporting and reconnecting.
- tokenStream → const MotionAiStyle
-
Mono-terminal token characters simulated streaming in real-time.
- tokenPrediction → const MotionAiStyle
-
AI text token generation typing text streams with glowing cursors.
- neuralPulse → const MotionAiStyle
-
Neuron branches flashing electric pulses and synapse network signals.
- tensorFlow → const MotionAiStyle
-
3D-perspective floating data cube matrices translating along streams.
- aiEye → const MotionAiStyle
-
Robotic sci-fi iris eye focusing, dilating, and sweeping scanlines.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MotionAiStyle> - A constant List of the values in this enum, in order of their declaration.