loaders/builder/motion_builder library
Classes
- FloatEffect
- FloatEffect floats the child vertically up and down using a smooth sinusoidal timeline.
- GlitchEffect
- GlitchEffect executes broken RGB digital splits and skews over the child widget.
- GlowEffect
- GlowEffect adds a pulsing colored outer shadow or neon halo under/around the widget.
- MotionBuilder
- A compounding modular visual stack.
- MotionEffect
- Base abstract class for modular compound effects.
- OrbitEffect
- OrbitEffect rotates the widget child itself or orbits planetary nodes around it.
- RippleEffect
- RippleEffect draws pulsing circular neon waves expanding outwards behind the child.