GlowEffect class
GlowEffect adds a pulsing colored outer shadow or neon halo under/around the widget.
- Inheritance
-
- Object
- MotionEffect
- GlowEffect
Constructors
- GlowEffect({required Color color, double blurRadius = 12.0, double spreadRadius = 1.0})
-
const
Properties
- blurRadius → double
-
final
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spreadRadius → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
BuildContext context, Widget child, double progress) → Widget -
Wraps the child widget with this specific visual effect.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited