OrbitEffect class
OrbitEffect rotates the widget child itself or orbits planetary nodes around it.
- Inheritance
-
- Object
- MotionEffect
- OrbitEffect
Constructors
- OrbitEffect({double radius = 40.0, double speed = 1.0})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
BuildContext context, Widget child, double progress) → Widget -
Wraps the child widget with this specific visual effect.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited