MotionNatureStyle enum

Nature Category styles & enums.

Inheritance
Available extensions

Values

firefly → const MotionNatureStyle

Fireflies drifting organically inside container spaces with breathing glows.

tornado → const MotionNatureStyle

3D tornado wind vortex drawing particle dust upwards in spirals.

volcano → const MotionNatureStyle

Periodic volcanic molten eruptions shooting magma sparks under gravity.

leafWind → const MotionNatureStyle

Leaves falling gracefully, drifting along lateral sine wind currents.

solarEclipse → const MotionNatureStyle

Moon overlapping the sun creating corona solar flares and ambient shifts.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MotionNatureStyle>
A constant List of the values in this enum, in order of their declaration.