MotionPhysicsStyle enum
Physics Category styles & enums.
Values
- pendulum → const MotionPhysicsStyle
-
Newton's Cradle swing momentum transferring kinetic collision energy.
- bounceChain → const MotionPhysicsStyle
-
Reactive interlocking spring nodes transferring kinetic wave pulses.
- gravityOrbit → const MotionPhysicsStyle
-
Orbital gravity decay particles accelerating around a massive nucleus.
- fluidParticle → const MotionPhysicsStyle
-
Viscosity particle fluid simulation with pressure attraction equations.
- sandSimulation → const MotionPhysicsStyle
-
Gravity-falling sand particles accumulating at the bottom with flow physics.
- magneticField → const MotionPhysicsStyle
-
Iron filings aligning dynamically towards rotating magnetic field poles.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MotionPhysicsStyle> - A constant List of the values in this enum, in order of their declaration.