refreshDuration property
The minimum duration the refresh indicator remains visible before hiding. Defaults to 3 seconds to let the premium visual animations run fully.
Implementation
final Duration refreshDuration;
The minimum duration the refresh indicator remains visible before hiding. Defaults to 3 seconds to let the premium visual animations run fully.
final Duration refreshDuration;